% lin2mel - matrix to warp linear scale power spectra to mel scale
%
% lin2mel :: 
%    N:natural      ~'size of FFT used to compute spectra',
%    nonneg         ~'sampling frequency',
%    [[1,2]->freq]  ~'upper and lower frequency limits',
%    L:natural      ~'number of mel bands to compute' 
% -> [[L,dftbins(N)]].

function melW=lin2mel(N,fs,flim,L)
	melW = tri_filterbank_aa(melspace(flim(1),min(flim(2),fs/2),L+2),binmap(0,fs/2,dftbins(N)));
end
